@@ -1,32 +1,36 @@
-#!/usr/bin/python3
-#
-# The Qubes OS Project, http://www.qubes-os.org
+# The Qubes OS Project, https://www.qubes-os.org/
 #
 # Copyright (C) 2012  Agnieszka Kostrzewa <agnieszka.kostrzewa@gmail.com>
 # Copyright (C) 2012  Marek Marczykowski <marmarek@mimuw.edu.pl>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License along
-# with this program; if not, see <http://www.gnu.org/licenses/>.
-#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
+
+
 import sys
 import os
 from functools import partial
-from PyQt5 import QtWidgets, Qt  # pylint: disable=import-error
+from PyQt6 import QtWidgets, QtCore  # pylint: disable=import-error
 from qubesadmin import Qubes
 from . import ui_logdlg   # pylint: disable=no-name-in-module
 from . import clipboard
 
+# this is needed for icons to actually work
+# pylint: disable=unused-import, no-name-in-module
+from . import resources
+
 # Display only this size of log
 LOG_DISPLAY_SIZE = 1024*1024
 
@@ -43,8 +47,8 @@ class LogDialog(ui_logdlg.Ui_LogDialog, QtWidgets.QDialog):
 
         self.setupUi(self)
         self.setWindowFlags(self.windowFlags() |
-                            Qt.Qt.WindowMaximizeButtonHint |
-                            Qt.Qt.WindowMinimizeButtonHint)
+                            QtCore.Qt.WindowType.WindowMaximizeButtonHint |
+                            QtCore.Qt.WindowType.WindowMinimizeButtonHint)
 
         self.copy_to_qubes_clipboard.clicked.connect(
             self.copy_to_clipboard_triggered)
@@ -89,7 +93,7 @@ def main():
     log_window = LogDialog(qubes_app, sys.argv[1:])
     log_window.show()
 
-    qt_app.exec_()
+    qt_app.exec()
     qt_app.exit()
 
 
