@@ -1,31 +1,37 @@
 #!/usr/bin/python3
 #
-# The Qubes OS Project, http://www.qubes-os.org
+# The Qubes OS Project, https://www.qubes-os.org/
 #
-# Copyright (C) 2018  Marta Marczykowska-Górecka
-# <marmarta@invisiblethingslab.com>
+# Copyright (C) 2018 Marta Marczykowska-Górecka
+#                                       <marmarta@invisiblethingslab.com>
 #
-# This program is free software; you can redistribute it and/or
-# modify it under the terms of the GNU General Public License
-# as published by the Free Software Foundation; either version 2
-# of the License, or (at your option) any later version.
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License along
-# with this program; if not, see <http://www.gnu.org/licenses/>.
-#
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
 
+
 from qubesadmin import exc
 
-from PyQt5 import QtWidgets, QtGui, QtCore  # pylint: disable=import-error
+from PyQt6 import QtWidgets, QtGui, QtCore  # pylint: disable=import-error
 
 from . import ui_templatemanager  # pylint: disable=no-name-in-module
 from . import utils
+from . import common_threads
+
+# this is needed for icons to actually work
+# pylint: disable=unused-import, no-name-in-module
+from . import resources
 
 column_names = ['State', 'Qube', 'Current template', 'New template']
 
@@ -33,6 +39,8 @@ column_names = ['State', 'Qube', 'Current template', 'New template']
 class TemplateManagerWindow(
         ui_templatemanager.Ui_MainWindow, QtWidgets.QMainWindow):
 
+    progress_signal = QtCore.pyqtSignal(int)
+
     def __init__(self, qt_app, qubes_app, dispatcher, parent=None):
         # pylint: disable=unused-argument
         super().__init__(parent)
@@ -45,15 +53,24 @@ class TemplateManagerWindow(
         self.rows_in_table = {}
         self.templates = []
         self.timers = []
+        self.dialog = None
+        self.thread = None
 
         self.prepare_lists()
         self.initialize_table_events()
 
-        self.buttonBox.button(QtWidgets.QDialogButtonBox.Ok).clicked.connect(
+        self.buttonBox.button(
+            QtWidgets.QDialogButtonBox.StandardButton.Ok).clicked.connect(
             self.apply)
         self.buttonBox.button(
-            QtWidgets.QDialogButtonBox.Cancel).clicked.connect(self.cancel)
-        self.buttonBox.button(QtWidgets.QDialogButtonBox.Reset).clicked.connect(
+            QtWidgets.QDialogButtonBox.StandardButton.Ok).setText('Apply')
+        self.buttonBox.button(
+            QtWidgets.QDialogButtonBox.StandardButton.Cancel).clicked.connect(
+            self.cancel)
+        self.buttonBox.button(
+            QtWidgets.QDialogButtonBox.StandardButton.Cancel).setText('Close')
+        self.buttonBox.button(
+            QtWidgets.QDialogButtonBox.StandardButton.Reset).clicked.connect(
             self.reset)
 
         self.change_all_combobox.currentIndexChanged.connect(
@@ -63,8 +80,9 @@ class TemplateManagerWindow(
         self.vm_list.show()
 
     def setup_application(self):
-        self.qt_app.setApplicationName(self.tr("Template Manager"))
+        self.qt_app.setApplicationName(self.tr("Template Switcher"))
         self.qt_app.setWindowIcon(QtGui.QIcon.fromTheme("qubes-manager"))
+        self.qt_app.setDesktopFileName("qubes-template-switcher")
 
     def prepare_lists(self):
         self.templates = [vm.name for vm in self.qubes_app.domains
@@ -161,7 +179,7 @@ class TemplateManagerWindow(
         if index == column_names.index('New template') or \
                 index == column_names.index('State'):
             self.vm_list.horizontalHeader().setSortIndicator(
-                -1, QtCore.Qt.AscendingOrder)
+                -1, QtCore.Qt.SortOrder.AscendingOrder)
 
     def clear_selection(self):
         for row in self.rows_in_table.values():
@@ -179,9 +197,12 @@ class TemplateManagerWindow(
                     row.new_item.findText(selected_template))
 
         self.change_all_combobox.setCurrentIndex(0)
+        self.clear_selection()
 
     def table_double_click(self, row, column):
         template_column = column_names.index('Current template')
+        current_state = self.vm_list.cellWidget(
+            row, column_names.index('State')).isChecked()
 
         if column != template_column:
             return
@@ -194,16 +215,13 @@ class TemplateManagerWindow(
                 checkbox = self.vm_list.cellWidget(
                     row_number, column_names.index('State'))
                 if checkbox:
-                    if row_number == row:
-                        # this is because double click registers as a
-                        # single click and a double click
-                        checkbox.setChecked(False)
-                    else:
-                        checkbox.setChecked(True)
+                    checkbox.setChecked(not current_state)
 
     def table_click(self, row, column):
         if column == column_names.index('New template'):
             return
+        if column == column_names.index('Current template'):
+            return
 
         checkbox = self.vm_list.cellWidget(row, column_names.index('State'))
         if not checkbox:
@@ -222,14 +240,31 @@ class TemplateManagerWindow(
         self.close()
 
     def apply(self):
-        errors = {}
-        for vm, row in self.rows_in_table.items():
-            if row.new_item and row.new_item.changed:
-                try:
-                    setattr(self.qubes_app.domains[vm],
-                            'template', row.new_item.currentText())
-                except Exception as ex:  # pylint: disable=broad-except
-                    errors[vm] = str(ex)
+        items_to_change = [
+            (vm, row) for vm, row in self.rows_in_table.items()
+            if row.new_item and row.new_item.changed]
+
+        # show a "in progress" dialog
+        self.dialog = QtWidgets.QProgressDialog(
+            "Changing templates...", None, 0, len(items_to_change), self)
+        self.dialog.setCancelButton(None)
+        self.dialog.setModal(True)
+        self.dialog.show()
+        self.progress_signal.connect(self.on_progress_changed)
+        self.thread = common_threads.ChangeTemplatesThread(self,
+                                                           items_to_change,
+                                                           self.qubes_app)
+        self.thread.finished.connect(self.finish_changes)
+        self.thread.start()
+
+    def on_progress_changed(self, value):
+        self.dialog.setValue(value)
+
+    def finish_changes(self):
+        self.dialog.hide()
+
+        errors = self.thread.errors
+
         if errors:
             error_messages = [vm + ": " + error for vm, error in errors.items()]
             QtWidgets.QMessageBox.warning(
@@ -238,7 +273,14 @@ class TemplateManagerWindow(
                 self.tr(
                     "Errors encountered on template change in the following "
                     "qubes: <br> {}.").format("<br> ".join(error_messages)))
-        self.close()
+
+        for vm, row in self.rows_in_table.items():
+            if row.new_item and row.new_item.changed:
+                vm_object = self.qubes_app.domains[vm]
+
+                if vm_object.template.name == row.new_item.currentText():
+                    row.new_item.reset_start_value()
+                    row.current_item.reset_template_name()
 
 
 class VMNameItem(QtWidgets.QTableWidgetItem):
@@ -288,6 +330,9 @@ class CurrentTemplateItem(QtWidgets.QTableWidgetItem):
             return self.vm.name < other.vm.name
         return self.text() < other.text()
 
+    def reset_template_name(self):
+        self.setText(self.vm.template.name)
+
 
 class NewTemplateItem(QtWidgets.QComboBox):
     def __init__(self, vm, templates, table_widget):
@@ -314,6 +359,11 @@ class NewTemplateItem(QtWidgets.QComboBox):
     def reset_choice(self):
         self.setCurrentIndex(self.findText(self.start_value))
 
+    def reset_start_value(self):
+        self.start_value = self.currentText()
+        self.changed = False
+        self.setStyleSheet('font-weight: normal')
+
 
 class VMRow:
     # pylint: disable=too-few-public-methods
