@@ -1,5 +1,4 @@
-#
-# The Qubes OS Project, https://www.qubes-os.org
+# The Qubes OS Project, https://www.qubes-os.org/
 #
 # Copyright (C) 2012  Agnieszka Kostrzewa <agnieszka.kostrzewa@gmail.com>
 # Copyright (C) 2012  Marek Marczykowski-Górecki
@@ -8,9 +7,9 @@
 # Copyright (C) 2020  Marta Marczykowska-Górecka
 #                       <marmarta@invisiblethingslab.com>
 #
-# This program is free software: you can redistribute it and/or modify
+# This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 2 of the License, or
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -18,9 +17,11 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# You should have received a copy of the GNU General Public License along
+# with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #
+
 import itertools
 import os
 import re
@@ -31,8 +32,13 @@ from contextlib import suppress
 import sys
 from qubesadmin import events
 from qubesadmin import exc
+import qubesimgconverter
+import xdg.BaseDirectory
+import pathlib
+import shutil
+import copy
 
-from PyQt5 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
+from PyQt6 import QtWidgets, QtCore, QtGui  # pylint: disable=import-error
 import qasync
 
 
@@ -49,6 +55,25 @@ import qasync
 # - just a list, no properties or defaults, just a nice list with a "current"
 #       value - initialize_widget
 
+def set_organization():
+    """set the organization and config home directory for Qt based Apps."""
+    # migrate old config file to the unified config directory
+    # TODO: remove the below block when Qubes R4.3 becomes End-of-Life
+    old_config_home = xdg.BaseDirectory.xdg_config_home + \
+        '/The Qubes Project'
+    new_config_home = xdg.BaseDirectory.xdg_config_home + '/qubes-os'
+    config_file = 'qubes-qube-manager.conf'
+    old_config_file = old_config_home + '/' + config_file
+    new_config_file = new_config_home + '/' + config_file
+    if os.path.isfile(old_config_file) and \
+            not os.path.isfile(new_config_file):
+        pathlib.Path(new_config_home).mkdir(parents=True, exist_ok=True)
+        shutil.copy(old_config_file, new_config_file)
+
+    QtCore.QCoreApplication.setOrganizationName('qubes-os')
+    QtCore.QCoreApplication.setOrganizationDomain('qubes-os.org')
+    QtCore.QCoreApplication.setApplicationName('qubes-qube-manager')
+
 def is_internal(vm):
     """checks if the VM is either an AdminVM or has the 'internal' features"""
     try:
@@ -81,8 +106,8 @@ class SizeSpinBox(QtWidgets.QSpinBox):
 
         self.pattern = r'(\d+\.?\d?) ?(GiB|MiB)'
         self.regex = re.compile(self.pattern)
-        self.validator = QtGui.QRegExpValidator(QtCore.QRegExp(
-            self.pattern), self)
+        self.validator = QtGui.QRegularExpressionValidator(
+            QtCore.QRegularExpression(self.pattern), self)
 
     def textFromValue(self, v: int) -> str:
         if v > 1024:
@@ -109,7 +134,7 @@ class QubeManagerToolBar(QtWidgets.QToolBar): # pylint: disable=too-few-public-m
     def __init__(self, parent=None):
         super().__init__(parent)
     def event(self, e):
-        if e.type() == QtCore.QEvent.Leave:
+        if e.type() == QtCore.QEvent.Type.Leave:
             return True
         return super().event(e)
 
@@ -177,7 +202,8 @@ def initialize_widget(widget, choices, selected_value=None,
 
 def initialize_widget_for_property(*, widget, choices, holder, property_name,
                                    allow_default=False, icon_getter=None,
-                                   add_current_label=True):
+                                   add_current_label=True,
+                                   default_text_provider=None):
     """
     populates widget (ListBox or ComboBox) with items, based on a listed
     property. Supports discovering the system default for the given property
@@ -193,8 +219,12 @@ def initialize_widget_for_property(*, widget, choices, holder, property_name,
     :param icon_getter: a function applied to values (from choices) that
         returns a QIcon to be used as a item icon; default None
     :param add_current_label: if initial value should be labelled as (current)
+    :param default_text_provider: a function that will calculate the text for
+        the default option using the property holder and property value as
+        input
     :return:
     """
+    choices_copy = copy.copy(choices)
     if allow_default:
         try:
             default_property = holder.property_get_default(property_name)
@@ -202,9 +232,15 @@ def initialize_widget_for_property(*, widget, choices, holder, property_name,
             default_property = "ERROR: unavailable"
         if default_property is None:
             default_property = "none"
-        choices.append(
-            (translate("default ({})").format(default_property),
-             qubesadmin.DEFAULT))
+        if default_text_provider is None:
+            choices_copy.append(
+                (translate("default ({})").format(default_property),
+                qubesadmin.DEFAULT))
+        else:
+            choices_copy.append(
+                (translate("default ({})").format(
+                    default_text_provider(holder, default_property)
+                ), qubesadmin.DEFAULT))
 
     # calculate current (can be default)
     try:
@@ -218,7 +254,7 @@ def initialize_widget_for_property(*, widget, choices, holder, property_name,
         current_value = getattr(holder, property_name)
 
     initialize_widget(widget,
-                      choices,
+                      choices_copy,
                       selected_value=current_value,
                       icon_getter=icon_getter,
                       add_current_label=add_current_label)
@@ -494,7 +530,7 @@ def handle_exception(exc_type, exc_value, exc_traceback):
 
     msg_box = QtWidgets.QMessageBox()
     msg_box.setDetailedText(strace)
-    msg_box.setIcon(QtWidgets.QMessageBox.Critical)
+    msg_box.setIcon(QtWidgets.QMessageBox.Icon.Critical)
     msg_box.setWindowTitle(QtCore.QCoreApplication.translate(
         "ManagerUtils", "Houston, we have a problem..."))
     msg_box.setText(QtCore.QCoreApplication.translate(
@@ -503,10 +539,11 @@ def handle_exception(exc_type, exc_value, exc_traceback):
                         "<b><i>{0}</i></b><br/>at line <b>{1}</b><br/>of file "
                         "{2}.<br/><br/>").format(error, line, filename))
 
-    msg_box.exec_()
+    msg_box.exec()
 
 
 def run_asynchronous(window_class):
+    set_organization()
     qt_app = QtWidgets.QApplication(sys.argv)
 
     translator = QtCore.QTranslator(qt_app)
@@ -518,8 +555,6 @@ def run_asynchronous(window_class):
     qt_app.installTranslator(translator)
     QtCore.QCoreApplication.installTranslator(translator)
 
-    qt_app.setOrganizationName("The Qubes Project")
-    qt_app.setOrganizationDomain("http://qubes-os.org")
     qt_app.lastWindowClosed.connect(loop_shutdown)
 
     qubes_app = qubesadmin.Qubes()
@@ -550,6 +585,7 @@ def run_asynchronous(window_class):
 
 
 def run_synchronous(window_class):
+    set_organization()
     qt_app = QtWidgets.QApplication(sys.argv)
 
     translator = QtCore.QTranslator(qt_app)
@@ -561,9 +597,6 @@ def run_synchronous(window_class):
     qt_app.installTranslator(translator)
     QtCore.QCoreApplication.installTranslator(translator)
 
-    qt_app.setOrganizationName("The Qubes Project")
-    qt_app.setOrganizationDomain("http://qubes-os.org")
-
     sys.excepthook = handle_exception
 
     qubes_app = qubesadmin.Qubes()
@@ -575,7 +608,30 @@ def run_synchronous(window_class):
 
     window.show()
 
-    qt_app.exec_()
+    qt_app.exec()
     qt_app.exit()
 
     return window
+
+
+def tint_qimage(source: QtGui.QImage, color: str) -> QtGui.QImage:
+    """Use qubesimgconverter.Image.tint() to tint a PyQt6.QtGui.QImage"""
+    assert isinstance(source, QtGui.QImage)
+    size_bytes = source.width() * source.height() * 4
+    if not size_bytes:
+        # Could not tint empty image
+        return source
+    source = source.convertToFormat(QtGui.QImage.Format.Format_RGBA8888)
+    internal_data = source.constBits()
+    internal_data.setsize(size_bytes)
+    raw_data = bytes(internal_data)
+    tinted_image = qubesimgconverter.Image(
+        raw_data, (source.width(), source.height())
+    ).tint(color)
+    destination = QtGui.QImage(
+        tinted_image.data,
+        tinted_image.width,
+        tinted_image.height,
+        QtGui.QImage.Format.Format_RGBA8888,
+    )
+    return destination
